package aQute.bnd.make;

import java.io.*;
import java.util.*;
import java.util.regex.*;

import aQute.bnd.service.*;
import aQute.lib.osgi.*;

public class MakeBnd implements MakePlugin {
    final static Pattern JARFILE = Pattern.compile("(.+)\\.(jar|ipa)");

    public Resource make(Builder builder, String destination,
            Map<String, String> argumentsOnMake) throws Exception {
        String type = (String) argumentsOnMake.get("type");
        if (!"bnd".equals(type))
            return null;

        String recipe = (String) argumentsOnMake.get("recipe");
        if (recipe == null) {
            builder.error("No recipe specified on a make instruction for "
                    + destination);
            return null;
        }
        File bndfile = builder.getFile(recipe);
        if (bndfile.isFile()) {
            Builder bchild = new Builder();
            bchild.setProperties(bndfile);
            bchild.setBase(builder.getBase());

            //
            // Get a copy of all our options so we follow the same rules
            // unless explicitly overridden.
            //
            for (Object element : builder.getProperties().keySet()) {
                String key = (String) element;
                if ((key.startsWith("-") || Character
                        .isLowerCase(key.charAt(0)))
                        && !bchild.getProperties().containsKey(key)) {
                    bchild.setProperty(key, builder.getProperty(key));
                }
            }

            //
            // Copy our classpath
            //
            for (Jar jar : builder.getClasspath())
                bchild.addClasspath(jar);

            String p = builder.getProperty("p");
            if (p == null)
                p = builder.getBase().getName();
            bchild.setProperty("p", p);

            Jar jar = bchild.build();
            Jar dot = builder.getTarget();

            if (builder.hasSources()) {
                for (String key : jar.getResources().keySet()) {
                    if (key.startsWith("OSGI-OPT/src"))
                        dot.putResource(key, (Resource) jar.getResource(key));
                }
            }
            builder.getInfo(bchild, bndfile.getName() +": ");
            return new JarResource(jar);
        } else
            return null;
    }

}
